@@ -1,4 +1,4 @@
-from .labeledcontainer import LabeledContainer
+from . import LabeledContainer
 
 class LabeledRadioButtonGroup(LabeledContainer):
    def __init__(self, master, **kw):
@@ -11,9 +11,6 @@ class LabeledRadioButtonGroup(LabeledContainer):
    def getValueText(self):
       return self.getSmartWidget((self.getValue(), 0))["text"]
    
-   def reloadValue(self):
-      super().reloadValue()
-   
    def _inflateChildren(self):
       for child in self._baseContainerChildren:
          if "type" not in child:
