@@ -2,10 +2,12 @@ from tkinter.ttk import Checkbutton as TtkCheckbutton
 from .smartwidget import SmartWidget
 
 class Checkbutton(SmartWidget, TtkCheckbutton):
-   def __init__(self, master = None, **kw):
-      SmartWidget._setVariable(kw, "BooleanVar", setHasValueBuffer = False, variableKey = "variable")
+   def __init__(self, master, **kw):
+      hasValueBuffer = kw.pop("hasValueBuffer", False)
+      
+      SmartWidget._setVariable(kw, "BooleanVar", variableKey = "variable")
       
       SmartWidget.__init__(self, master, **kw)
       
-      if self.hasValueBuffer:
+      if hasValueBuffer:
          self._initValueAndTraceAdd()
