@@ -1,6 +1,10 @@
 from commonutils import StaticUtils
 from numbers import Number
+# pylint: disable = unused-import
 from tkinter import BooleanVar, IntVar, StringVar # _setVariable()
+# pylint: enable = unused-import
+from tkinter.ttk import Widget
+from ...json import Config
 
 class SmartWidget:
    __FONT = None
@@ -8,7 +12,7 @@ class SmartWidget:
    def __init__(self, master, **kw):
       self._namePrefix = kw.pop("namePrefix")
       self._parentContainer = master
-      self._smartWidgetConfig = kw.pop("config")
+      self._smartWidgetStorage = kw.pop("storage")
       self._smartWidgetGrid = kw.pop("grid")
       self._smartWidgetName = kw.pop("name", None)
       
@@ -42,16 +46,13 @@ class SmartWidget:
       
       if self.__value:
          self._defaultValue = self.__value.get()
-         self.__valueKeyInStorage = kw.pop("valueKeyInStorage")
       
-      self.__processValueDomains(kw)
+      self.__valueDomains = tuple(map(self.__processValueDomains, kw.pop("valueDomains", [])))
       
-      if not self.__value and len(self.__valueDomains):
-         raise ValueError(f"'valueDomain(s)' specified for '{self._smartWidgetName}', but there's no value to serialize")
+      if not self.__value and self.__valueDomains:
+         raise ValueError(f"'valueDomains' specified for '{self._smartWidgetName}', but there's no value to serialize")
       
       if self.__class__._TKINTER_BASE:
-         from tkinter.ttk import Widget
-         
          if issubclass(self.__class__._TKINTER_BASE, Widget) and "style" not in kw:
             kw["style"] = self.__class__.STYLE
          
@@ -67,7 +68,7 @@ class SmartWidget:
       self.__class__._TKINTER_BASE.grid(self, **StaticUtils.mergeJson(kw, self._smartWidgetGrid, True))
    
    def reloadValue(self):
-      if len(self.__valueDomains):
+      if self.__valueDomains:
          self.__loadValue()
    
    @property
@@ -94,14 +95,10 @@ class SmartWidget:
       if not self._smartWidgetName:
          raise ValueError("Can't serialize nameless widgets")
       
-      storage = self._smartWidgetConfig
-      
-      for keys in (("values", ""), *self.__valueDomains):
-         for k in keys:
-            storage = StaticUtils.setIfAbsentAndGet(storage, k, dict())
+      storage = self._smartWidgetStorage
       
       for domain in self.__valueDomains:
-         storage = StaticUtils.setIfAbsentAndGet(storage, str(self._topLevelContainer.getSmartWidget(*domain).getValue()), dict())
+         storage = StaticUtils.setIfAbsentAndGet(storage, f"{'.'.join(domain)}={str(self._topLevelContainer.getSmartWidget(*domain).getValue())}", dict())
       
       for name in (*self._namePrefix, self._smartWidgetName):
          storage = StaticUtils.setIfAbsentAndGet(storage, name, dict())
@@ -112,34 +109,24 @@ class SmartWidget:
       self.__loadValue()
       
       def _set(*_):
-         self._getValueStorage()[""] = self.__value.get()
+         self._getValueStorage()["value"] = self.__value.get()
       
       self.__value.trace_add("write", _set)
    
    def __loadValue(self):
-      self.__value.set(StaticUtils.setIfAbsentAndGet(self._getValueStorage(), self.__valueKeyInStorage, self._defaultValue))
+      self.__value.set(StaticUtils.setIfAbsentAndGet(self._getValueStorage(), "value", self._defaultValue))
    
-   def __processValueDomains(self, kw):
-      domainPresent = "valueDomain" in kw
+   def __processValueDomains(self, valueDomain):
+      valueDomain = valueDomain.split(".")
       
-      if all((domainPresent, "valueDomains" in kw)):
-         raise ValueError(f"Only one of {('valueDomain', 'valueDomains')} can be present")
+      if not valueDomain[0]:
+         valueDomain[:1] = self._namePrefix
       
-      self.__valueDomains = [kw.pop("valueDomain")] if domainPresent else kw.pop("valueDomains", [])
-      
-      for i in range(len(self.__valueDomains)):
-         if isinstance(self.__valueDomains[i], str) and len(self.__valueDomains[i]):
-            self.__valueDomains[i] = self.__valueDomains[i].split(".")
-            
-            if not len(self.__valueDomains[i][0]):
-               self.__valueDomains[i][:1] = self._namePrefix
-         
-         elif not isinstance(self.__valueDomains[i], list):
-            raise ValueError()
+      return valueDomain
    
    @staticmethod
-   def setFont(font):
-      SmartWidget.__FONT = font
+   def setFont():
+      SmartWidget.__FONT = Config["widgetFont"]
    
    @staticmethod
    def _setFont(kw):
@@ -147,12 +134,12 @@ class SmartWidget:
          kw["font"] = SmartWidget.__FONT
    
    @staticmethod
-   def _setVariable(kw, defaultTypeName, defaultValueKey = "value", valueKeyInStorage = "", variableKey = None):
+   def _setVariable(kw, defaultTypeName, defaultValueKey = "value", variableKey = None):
+      # pylint: disable = eval-used
       value = eval(f"{kw.pop('valueType', defaultTypeName)}()")
       value.set(kw.get(defaultValueKey, value.get()))
       
       kw["value"] = value
-      kw["valueKeyInStorage"] = valueKeyInStorage
       
       if variableKey:
          kw[variableKey] = value
